@@ -3,11 +3,8 @@ import typing
 
 class LanternNight:
     """Lantern Night event related information."""
-    def __init__(self,
-                 nights_on_cooldown: int,
-                 genuine: bool,
-                 manual: bool,
-                 next_night_is_lantern_night: bool):
+
+    def __init__(self, nights_on_cooldown: int, genuine: bool, manual: bool, next_night_is_lantern_night: bool):
         self.nights_on_cooldown: int = nights_on_cooldown
         """How many nights before the next lantern night can happen."""
 
@@ -21,8 +18,10 @@ class LanternNight:
         """Was a boss just defeated, making the next night a Lantern Night?"""
 
     def __repr__(self):
-        return f"WorldLanternNight(nights_on_cooldown={self.nights_on_cooldown}," \
-               f" genuine={self.genuine}, manual={self.manual}, nights_on_cooldown={self.nights_on_cooldown})"
+        return (
+            f"WorldLanternNight(nights_on_cooldown={self.nights_on_cooldown},"
+            f" genuine={self.genuine}, manual={self.manual}, nights_on_cooldown={self.nights_on_cooldown})"
+        )
 
     @property
     def is_active(self):
