@@ -4,12 +4,10 @@ from ..enums import ItemType, PrefixType
 
 class ItemStack:
     """A stack of a certain item."""
+
     __slots__ = "type", "quantity", "prefix"
 
-    def __init__(self,
-                 type_: ItemType,
-                 quantity: int = 1,
-                 prefix: Optional[PrefixType] = None):
+    def __init__(self, type_: ItemType, quantity: int = 1, prefix: Optional[PrefixType] = None):
 
         self.type: ItemType = type_
         """The type of item represented in this stack."""
