@@ -7,5 +7,4 @@ from .liquid import Liquid
 from .tile import Tile
 from .tilematrix import TileMatrix
 
-__all__ = ["Shape", "Wiring", "FrameImportantData", "Block",
-           "Wall", "Liquid", "Tile", "TileMatrix"]
+__all__ = ["Shape", "Wiring", "FrameImportantData", "Block", "Wall", "Liquid", "Tile", "TileMatrix"]
